A tour started, before its first step is shown.
Not called for a start() that did nothing because the tour was already completed.
start()
@override void didStartTour(String tour) => events.add('tour-start:$tour');