HintEvent class
What happened to one hint.
Handed to HintObserver.didShowHint and HintObserver.didDismissHint.
- Annotations
Constructors
- HintEvent({String? id, String? label, HintTrigger? trigger, String? showOnce})
-
Creates a hint event.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
The hint's Hint.analyticsId, when it has one.
final
- label → String?
-
The hint's text: its semantics label, message or title, whichever it has.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showOnce → String?
-
The Hint.showOnce key, when the hint has one.
final
- trigger → HintTrigger?
-
What opened the hint, when it was opened by a trigger.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited