open method
void
open(
- DismissibleHint hint
Registers hint as the open one, closing whichever hint held the floor.
Called by a hint as it opens, before its entry animation starts.
Implementation
void open(DismissibleHint hint) {
final DismissibleHint? previous = _current;
_current = hint;
if (previous != null && !identical(previous, hint)) {
previous.dismissForExclusivity();
}
}